@@ -52,7 +52,7 @@ sub withecho {
    retry:
    print STDERR "$cmd\n" if(!$opt_quiet);
    if(system(@_)) {
-      print STDERR "Command $cmd failed, how to continue now? [Qri?]: ";
+      print STDERR "Command $cmd failed in ".Cwd::getcwd.", how to continue now? [Qri?]: ";
       prompt:
       $ans = <STDIN>;
       if($ans =~ /^q\n/i) {
@@ -121,8 +121,8 @@ sub url {
    return $cacheUrl{$testpath} if($cacheUrl{$testpath});
    open($info, "svn info $testpath 2>/dev/null |");
    while(<$info>) { 
-      $URL=$1 if(/^Url:\W*(.+)\n/i); 
-      $PATH=$1 if(/^Path:\s*(.+)\n/i);
+      $URL=$1 if(/^Url\s*:\W*(.+)\n/i); 
+      $PATH=$1 if(/^Path\s*:\s*(.+)\n/i);
    };
    if($URL && close($info)) {
       $cacheUrl{$testpath}=$URL;
